Class OAuth2ClientConfigException

All Implemented Interfaces:
Serializable

public class OAuth2ClientConfigException extends OAuth2ClientException
Exception for configuration errors.
See Also:
  • Constructor Details

    • OAuth2ClientConfigException

      public OAuth2ClientConfigException(String message)
      Creates a new configuration exception with the specified message.
    • OAuth2ClientConfigException

      public OAuth2ClientConfigException(String message, Throwable cause)
      Creates a new configuration exception with the specified message and cause.