Record Class OAuth2Handler.AccessTokenResponse

java.lang.Object
java.lang.Record
com.mastercard.developer.oauth2.core.OAuth2Handler.AccessTokenResponse
Enclosing class:
OAuth2Handler

public static record OAuth2Handler.AccessTokenResponse(String tokenValue, Set<String> scopes, Instant expiry) extends Record
Model for the response from an OAuth2 token endpoint. See: RFC 6749 Section 5.1
  • Constructor Summary

    Constructors
    Constructor
    Description
    AccessTokenResponse(String tokenValue, Set<String> scopes, Instant expiry)
    Creates an instance of a AccessTokenResponse record class.
  • Method Summary

    Modifier and Type
    Method
    Description
    final boolean
    Indicates whether some other object is "equal to" this one.
    Returns the value of the expiry record component.
    final int
    Returns a hash code value for this object.
    Returns the value of the scopes record component.
    Returns the value of the tokenValue record component.
    final String
    Returns a string representation of this record class.

    Methods inherited from class java.lang.Object

    clone, getClass, notify, notifyAll, wait, wait, wait
  • Constructor Details

    • AccessTokenResponse

      public AccessTokenResponse(String tokenValue, Set<String> scopes, Instant expiry)
      Creates an instance of a AccessTokenResponse record class.
      Parameters:
      tokenValue - the value for the tokenValue record component
      scopes - the value for the scopes record component
      expiry - the value for the expiry record component
  • Method Details

    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with Objects::equals(Object,Object).
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • tokenValue

      public String tokenValue()
      Returns the value of the tokenValue record component.
      Returns:
      the value of the tokenValue record component
    • scopes

      public Set<String> scopes()
      Returns the value of the scopes record component.
      Returns:
      the value of the scopes record component
    • expiry

      public Instant expiry()
      Returns the value of the expiry record component.
      Returns:
      the value of the expiry record component