Record Class StaticScopeResolver

java.lang.Object
java.lang.Record
com.mastercard.developer.oauth2.core.scope.StaticScopeResolver
All Implemented Interfaces:
ScopeResolver

public record StaticScopeResolver(Set<String> scopes) extends Record implements ScopeResolver
A ScopeResolver that always returns a fixed list of scopes regardless of the URL.
  • Constructor Details

    • StaticScopeResolver

      public StaticScopeResolver(Set<String> scopes)
      Creates a new StaticScopeResolver with the given scopes. If the provided set is null, an empty set will be used instead.
  • Method Details

    • resolve

      public Set<String> resolve(String httpMethod, URL url)
      Description copied from interface: ScopeResolver
      Returns a set of scopes to request for an HTTP request to the given URL with the given method.
      Specified by:
      resolve in interface ScopeResolver
    • allScopes

      public Set<String> allScopes()
      Description copied from interface: ScopeResolver
      Returns all possible scopes that can be requested.
      Specified by:
      allScopes in interface ScopeResolver
    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with Objects::equals(Object,Object).
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • scopes

      public Set<String> scopes()
      Returns the value of the scopes record component.
      Returns:
      the value of the scopes record component