Package com.mastercard.developer.oauth2.core.scope
package com.mastercard.developer.oauth2.core.scope
-
ClassDescriptionResolves OAuth2 scopes for API requests.A
ScopeResolverthat always returns a fixed list of scopes regardless of the URL.
ScopeResolver that always returns a fixed list of scopes regardless of the URL.