Class HttpHeaders
- All Implemented Interfaces:
Serializable,Cloneable,Iterable<HttpHeaders.HttpHeader>,Collection<HttpHeaders.HttpHeader>,Set<HttpHeaders.HttpHeader>
Represents a set of HTTP headers.
- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic final recordRepresents a single header entry. -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionadd(StandardHttpHeader header, String value) Adds/replaces a header.booleanChecks if a header with the given name exists.Gets the value of the header with the given name.Methods inherited from class java.util.LinkedHashSet
spliteratorMethods inherited from class java.util.HashSet
add, clear, clone, contains, isEmpty, iterator, remove, size, toArray, toArrayMethods inherited from class java.util.AbstractSet
equals, hashCode, removeAllMethods inherited from class java.util.AbstractCollection
addAll, containsAll, retainAll, toStringMethods inherited from interface java.util.Collection
parallelStream, removeIf, stream, toArray
-
Constructor Details
-
HttpHeaders
public HttpHeaders()
-
-
Method Details
-
add
Adds/replaces a header. -
get
Gets the value of the header with the given name. -
contains
Checks if a header with the given name exists.
-