Uses of Enum Class
com.mastercard.developer.oauth2.http.StandardHttpHeader
Packages that use StandardHttpHeader
-
Uses of StandardHttpHeader in com.mastercard.developer.oauth2.http
Methods in com.mastercard.developer.oauth2.http that return StandardHttpHeaderModifier and TypeMethodDescriptionstatic StandardHttpHeaderReturns the enum constant of this class with the specified name.static StandardHttpHeader[]StandardHttpHeader.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in com.mastercard.developer.oauth2.http with parameters of type StandardHttpHeaderModifier and TypeMethodDescriptionHttpHeaders.add(StandardHttpHeader header, String value) Adds/replaces a header.