Uses of Enum Class
com.mastercard.developer.oauth2.internal.jose.JwsAlgorithm
Packages that use JwsAlgorithm
-
Uses of JwsAlgorithm in com.mastercard.developer.oauth2.internal.jose
Methods in com.mastercard.developer.oauth2.internal.jose that return JwsAlgorithmModifier and TypeMethodDescriptionstatic JwsAlgorithmDetermines the appropriate signing algorithm based on the key type.static JwsAlgorithmReturns the enum constant of this class with the specified name.static JwsAlgorithm[]JwsAlgorithm.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in com.mastercard.developer.oauth2.internal.jose with parameters of type JwsAlgorithmModifier and TypeMethodDescriptionstatic voidJws.sign(Jwt jwt, PrivateKey privateKey, JwsAlgorithm alg) Signs a JWT using the specified private key and algorithm.