Index

A B C D E F G H I J K L N O P R S T U V W 
All Classes and Interfaces|All Packages|Serialized Form

A

ACCEPT - Enum constant in enum class com.mastercard.developer.oauth2.http.StandardHttpHeader
 
AccessToken - Record Class in com.mastercard.developer.oauth2.core.access_token
Immutable model for an access token and its metadata.
AccessToken(String, Set<String>, Instant, String) - Constructor for record class com.mastercard.developer.oauth2.core.access_token.AccessToken
Creates a new access token without DPoP binding.
AccessToken(String, Set<String>, Instant, String, String) - Constructor for record class com.mastercard.developer.oauth2.core.access_token.AccessToken
Creates a new access token
AccessTokenFilter - Record Class in com.mastercard.developer.oauth2.core.access_token
Filter criteria for retrieving access tokens from the token store.
AccessTokenFilter(Optional<String>, Set<String>) - Constructor for record class com.mastercard.developer.oauth2.core.access_token.AccessTokenFilter
Creates a new filter with the specified criteria.
AccessTokenResponse(String, Set<String>, Instant) - Constructor for record class com.mastercard.developer.oauth2.core.OAuth2Handler.AccessTokenResponse
Creates an instance of a AccessTokenResponse record class.
accessTokenStore(AccessTokenStore) - Method in class com.mastercard.developer.oauth2.config.OAuth2Config.OAuth2ConfigBuilder
Sets the storage mechanism for caching access tokens.
AccessTokenStore - Interface in com.mastercard.developer.oauth2.core.access_token
Interface for caching and retrieving OAuth 2.0 access tokens.
adapter() - Method in record class com.mastercard.developer.oauth2.http.spring.webclient.OAuth2Filter
Returns the value of the adapter record component.
add(StandardHttpHeader, String) - Method in class com.mastercard.developer.oauth2.http.HttpHeaders
Adds/replaces a header.
addClaim(String, Object) - Method in class com.mastercard.developer.oauth2.internal.jose.Jwt
Adds a claim to the JWT payload.
addHeaderParam(String, Object) - Method in class com.mastercard.developer.oauth2.internal.jose.Jwt
Adds a parameter to the JWT header.
alg() - Method in enum class com.mastercard.developer.oauth2.internal.jose.JwsAlgorithm
Returns the algorithm name as used in JWT headers.
allScopes() - Method in interface com.mastercard.developer.oauth2.core.scope.ScopeResolver
Returns all possible scopes that can be requested.
allScopes() - Method in record class com.mastercard.developer.oauth2.core.scope.StaticScopeResolver
 
authenticator() - Method in class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient
 
authenticator(Authenticator) - Method in record class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient.Builder
 
AUTHORIZATION - Enum constant in enum class com.mastercard.developer.oauth2.http.StandardHttpHeader
 

B

build() - Method in class com.mastercard.developer.oauth2.config.OAuth2Config.OAuth2ConfigBuilder
Builds the OAuth2Config instance.
build() - Method in record class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient.Builder
 
builder() - Static method in class com.mastercard.developer.oauth2.config.OAuth2Config
Create a new builder for OAuth2Config.
Builder(OAuth2Config) - Constructor for record class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient.Builder
 
Builder(OAuth2Config, HttpClient.Builder) - Constructor for record class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient.Builder
Creates an instance of a Builder record class.
byJktAndScopes(String, Set<String>) - Static method in record class com.mastercard.developer.oauth2.core.access_token.AccessTokenFilter
Creates a filter for the specified JKT and scopes.
byScopes(Set<String>) - Static method in record class com.mastercard.developer.oauth2.core.access_token.AccessTokenFilter
Creates a filter for the specified scopes.

C

clientId() - Method in record class com.mastercard.developer.oauth2.core.access_token.AccessToken
Returns the value of the clientId record component.
clientId(String) - Method in class com.mastercard.developer.oauth2.config.OAuth2Config.OAuth2ConfigBuilder
Sets the OAuth2 client identifier.
clientKey(PrivateKey) - Method in class com.mastercard.developer.oauth2.config.OAuth2Config.OAuth2ConfigBuilder
Sets the private key used for client authentication via private_key_jwt.
clockSkewTolerance(Duration) - Method in class com.mastercard.developer.oauth2.config.OAuth2Config.OAuth2ConfigBuilder
Sets the tolerance for clock skew when validating token expiration.
close() - Method in class com.mastercard.developer.oauth2.http.apache.OAuth2HttpClient
 
close(CloseMode) - Method in class com.mastercard.developer.oauth2.http.apache.OAuth2HttpClient
 
close(Response) - Method in interface com.mastercard.developer.oauth2.http.HttpAdapter
Closes a response and releases resources.
com.mastercard.developer.oauth2.config - package com.mastercard.developer.oauth2.config
 
com.mastercard.developer.oauth2.config.exception - package com.mastercard.developer.oauth2.config.exception
 
com.mastercard.developer.oauth2.core - package com.mastercard.developer.oauth2.core
 
com.mastercard.developer.oauth2.core.access_token - package com.mastercard.developer.oauth2.core.access_token
 
com.mastercard.developer.oauth2.core.dpop - package com.mastercard.developer.oauth2.core.dpop
 
com.mastercard.developer.oauth2.core.scope - package com.mastercard.developer.oauth2.core.scope
 
com.mastercard.developer.oauth2.exception - package com.mastercard.developer.oauth2.exception
 
com.mastercard.developer.oauth2.http - package com.mastercard.developer.oauth2.http
 
com.mastercard.developer.oauth2.http.apache - package com.mastercard.developer.oauth2.http.apache
 
com.mastercard.developer.oauth2.http.feign - package com.mastercard.developer.oauth2.http.feign
 
com.mastercard.developer.oauth2.http.java - package com.mastercard.developer.oauth2.http.java
 
com.mastercard.developer.oauth2.http.okhttp3 - package com.mastercard.developer.oauth2.http.okhttp3
 
com.mastercard.developer.oauth2.http.spring.restclient - package com.mastercard.developer.oauth2.http.spring.restclient
 
com.mastercard.developer.oauth2.http.spring.webclient - package com.mastercard.developer.oauth2.http.spring.webclient
 
com.mastercard.developer.oauth2.internal.jose - package com.mastercard.developer.oauth2.internal.jose
 
com.mastercard.developer.oauth2.internal.json - package com.mastercard.developer.oauth2.internal.json
 
com.mastercard.developer.oauth2.internal.json.exception - package com.mastercard.developer.oauth2.internal.json.exception
 
com.mastercard.developer.oauth2.keys - package com.mastercard.developer.oauth2.keys
 
computeThumbprint() - Method in class com.mastercard.developer.oauth2.internal.jose.Jwk
Computes the JWK thumbprint as defined by RFC 7638.
config() - Method in record class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient.Builder
Returns the value of the config record component.
connectTimeout() - Method in class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient
 
connectTimeout(Duration) - Method in record class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient.Builder
 
contains(String) - Method in class com.mastercard.developer.oauth2.http.HttpHeaders
Checks if a header with the given name exists.
CONTENT_TYPE - Enum constant in enum class com.mastercard.developer.oauth2.http.StandardHttpHeader
 
cookieHandler() - Method in class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient
 
cookieHandler(CookieHandler) - Method in record class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient.Builder
 
createAccessTokenRequestBody(String, String, String) - Static method in class com.mastercard.developer.oauth2.core.OAuth2Handler
Creates a URL-encoded request body for an OAuth2 client credentials token request.
createClientAssertion(OAuth2Config) - Static method in class com.mastercard.developer.oauth2.core.OAuth2Handler
Creates a private_key_jwt client assertion for OAuth2 token requests.
createResourceRequestDPoP(OAuth2Config, String, String, String, String, String) - Static method in class com.mastercard.developer.oauth2.core.OAuth2Handler
Creates a DPoP proof token for resource access requests.
createTokenRequestDPoP(OAuth2Config, String, String) - Static method in class com.mastercard.developer.oauth2.core.OAuth2Handler
Creates a DPoP proof token for OAuth2 token endpoint requests.

D

delegate() - Method in record class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient.Builder
Returns the value of the delegate record component.
doExecute(HttpHost, ClassicHttpRequest, HttpContext) - Method in class com.mastercard.developer.oauth2.http.apache.OAuth2HttpClient
 
DPOP - Enum constant in enum class com.mastercard.developer.oauth2.http.StandardHttpHeader
 
DPOP_NONCE - Enum constant in enum class com.mastercard.developer.oauth2.http.StandardHttpHeader
 
DPoPKey - Interface in com.mastercard.developer.oauth2.core.dpop
Represents a DPoP key containing a key pair and its identifier.
dpopKeyProvider(DPoPKeyProvider) - Method in class com.mastercard.developer.oauth2.config.OAuth2Config.OAuth2ConfigBuilder
Sets the provider for DPoP key pairs used to generate DPoP proof tokens.
DPoPKeyProvider - Interface in com.mastercard.developer.oauth2.core.dpop
DPoP key provider used to supply keys for creating DPoP proofs.

E

equals(Object) - Method in record class com.mastercard.developer.oauth2.core.access_token.AccessToken
Indicates whether some other object is "equal to" this one.
equals(Object) - Method in record class com.mastercard.developer.oauth2.core.access_token.AccessTokenFilter
Indicates whether some other object is "equal to" this one.
equals(Object) - Method in record class com.mastercard.developer.oauth2.core.OAuth2Handler.AccessTokenResponse
Indicates whether some other object is "equal to" this one.
equals(Object) - Method in record class com.mastercard.developer.oauth2.core.scope.StaticScopeResolver
Indicates whether some other object is "equal to" this one.
equals(Object) - Method in record class com.mastercard.developer.oauth2.http.HttpHeaders.HttpHeader
Indicates whether some other object is "equal to" this one.
equals(Object) - Method in record class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient.Builder
Indicates whether some other object is "equal to" this one.
equals(Object) - Method in record class com.mastercard.developer.oauth2.http.spring.webclient.OAuth2Filter
Indicates whether some other object is "equal to" this one.
ES256 - Enum constant in enum class com.mastercard.developer.oauth2.internal.jose.JwsAlgorithm
 
execute(Request, Request.Options) - Method in class com.mastercard.developer.oauth2.http.feign.OAuth2Client
 
execute(Request, HttpAdapter<Request, Response>) - Method in class com.mastercard.developer.oauth2.core.OAuth2Handler
Main entry point that coordinates the entire OAuth2 flow for each intercepted request.
executor() - Method in class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient
 
executor(Executor) - Method in record class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient.Builder
 
expiresAt() - Method in record class com.mastercard.developer.oauth2.core.access_token.AccessToken
Returns the value of the expiresAt record component.
expiry() - Method in record class com.mastercard.developer.oauth2.core.OAuth2Handler.AccessTokenResponse
Returns the value of the expiry record component.

F

FAPI2SP_PRIVATE_KEY_DPOP - Enum constant in enum class com.mastercard.developer.oauth2.config.SecurityProfile
FAPI 2.0 Security Profile with private_key_jwt and DPoP.
filter(ClientRequest, ExchangeFunction) - Method in record class com.mastercard.developer.oauth2.http.spring.webclient.OAuth2Filter
 
followRedirects() - Method in class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient
 
followRedirects(HttpClient.Redirect) - Method in record class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient.Builder
 
fromJson(String) - Static method in class com.mastercard.developer.oauth2.internal.jose.Jwk
Parses a JWK from its JSON representation.
fromKey(Key) - Static method in enum class com.mastercard.developer.oauth2.internal.jose.JwsAlgorithm
Determines the appropriate signing algorithm based on the key type.
fromKey(PublicKey) - Static method in class com.mastercard.developer.oauth2.internal.jose.Jwk
Creates a JWK representation from a public key.

G

generateEcKeyPair(String) - Static method in class com.mastercard.developer.oauth2.keys.KeyGenerator
Generates an EC key pair with the specified curve.
generateRsaKeyPair(int) - Static method in class com.mastercard.developer.oauth2.keys.KeyGenerator
Generates an RSA key pair with the specified key size.
get() - Static method in class com.mastercard.developer.oauth2.http.UserAgent
Builds a stable user-agent string: Product/Version (Runtime; OS [OS Version]) Example: Mastercard-OAuth2-Client/1.0.0 (Java/17.0.2; Linux 5.15)
get(AccessTokenFilter) - Method in interface com.mastercard.developer.oauth2.core.access_token.AccessTokenStore
Retrieves an access token matching the specified filter criteria ("AND" logic).
get(AccessTokenFilter) - Method in class com.mastercard.developer.oauth2.core.access_token.InMemoryAccessTokenStore
 
get(String) - Method in class com.mastercard.developer.oauth2.http.HttpHeaders
Gets the value of the header with the given name.
getAccessTokenStore() - Method in class com.mastercard.developer.oauth2.config.OAuth2Config
 
getClientId() - Method in class com.mastercard.developer.oauth2.config.OAuth2Config
 
getClientKey() - Method in class com.mastercard.developer.oauth2.config.OAuth2Config
 
getClockSkewTolerance() - Method in class com.mastercard.developer.oauth2.config.OAuth2Config
 
getCurrentKey() - Method in interface com.mastercard.developer.oauth2.core.dpop.DPoPKeyProvider
Gets the current key to be used for signing DPoP proofs.
getCurrentKey() - Method in class com.mastercard.developer.oauth2.core.dpop.StaticDPoPKeyProvider
 
getDPoPKeyProvider() - Method in class com.mastercard.developer.oauth2.config.OAuth2Config
 
getHeader(Response, String) - Method in interface com.mastercard.developer.oauth2.http.HttpAdapter
Gets a header value from a response.
getInstance() - Static method in interface com.mastercard.developer.oauth2.internal.json.JsonProvider
Returns a singleton instance of a JsonProvider based on available libraries.
getIssuer() - Method in class com.mastercard.developer.oauth2.config.OAuth2Config
 
getKey(String) - Method in interface com.mastercard.developer.oauth2.core.dpop.DPoPKeyProvider
Returns a key by "kid" (useful in scenarios where the provider returns different key pairs over time).
getKey(String) - Method in class com.mastercard.developer.oauth2.core.dpop.StaticDPoPKeyProvider
 
getKeyId() - Method in interface com.mastercard.developer.oauth2.core.dpop.DPoPKey
Gets the key identifier ("kid" value that will be added to the DPoP proof header).
getKeyPair() - Method in interface com.mastercard.developer.oauth2.core.dpop.DPoPKey
Gets the key pair used for signing DPoP proofs.
getKid() - Method in class com.mastercard.developer.oauth2.config.OAuth2Config
 
getMethod(Request) - Method in interface com.mastercard.developer.oauth2.http.HttpAdapter
Extracts the HTTP method from a request.
getScopeResolver() - Method in class com.mastercard.developer.oauth2.config.OAuth2Config
 
getSerialized() - Method in class com.mastercard.developer.oauth2.internal.jose.Jwt
Returns the complete JWT in JWS compact serialization format.
getSigningInput() - Method in class com.mastercard.developer.oauth2.internal.jose.Jwt
Generates the signing input for the JWT (base64url-encoded header and payload separated by a dot).
getStatusCode(Response) - Method in interface com.mastercard.developer.oauth2.http.HttpAdapter
Gets the status code from a response.
getTokenEndpoint() - Method in class com.mastercard.developer.oauth2.config.OAuth2Config
 
getUrl(Request) - Method in interface com.mastercard.developer.oauth2.http.HttpAdapter
Extracts the URL from a request.
getUserAgent() - Method in class com.mastercard.developer.oauth2.config.OAuth2Config
 
GsonJsonProvider - Class in com.mastercard.developer.oauth2.internal.json
 
GsonJsonProvider() - Constructor for class com.mastercard.developer.oauth2.internal.json.GsonJsonProvider
 

H

handler() - Method in record class com.mastercard.developer.oauth2.http.spring.webclient.OAuth2Filter
Returns the value of the handler record component.
hashCode() - Method in record class com.mastercard.developer.oauth2.core.access_token.AccessToken
Returns a hash code value for this object.
hashCode() - Method in record class com.mastercard.developer.oauth2.core.access_token.AccessTokenFilter
Returns a hash code value for this object.
hashCode() - Method in record class com.mastercard.developer.oauth2.core.OAuth2Handler.AccessTokenResponse
Returns a hash code value for this object.
hashCode() - Method in record class com.mastercard.developer.oauth2.core.scope.StaticScopeResolver
Returns a hash code value for this object.
hashCode() - Method in record class com.mastercard.developer.oauth2.http.HttpHeaders.HttpHeader
Returns a hash code value for this object.
hashCode() - Method in record class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient.Builder
Returns a hash code value for this object.
hashCode() - Method in record class com.mastercard.developer.oauth2.http.spring.webclient.OAuth2Filter
Returns a hash code value for this object.
HttpAdapter<Request,Response> - Interface in com.mastercard.developer.oauth2.http
Abstraction for HTTP operations across different HTTP client implementations.
HttpHeader(String, String) - Constructor for record class com.mastercard.developer.oauth2.http.HttpHeaders.HttpHeader
Creates an instance of a HttpHeader record class.
HttpHeaders - Class in com.mastercard.developer.oauth2.http
Represents a set of HTTP headers.
HttpHeaders() - Constructor for class com.mastercard.developer.oauth2.http.HttpHeaders
 
HttpHeaders.HttpHeader - Record Class in com.mastercard.developer.oauth2.http
Represents a single header entry.

I

InMemoryAccessTokenStore - Class in com.mastercard.developer.oauth2.core.access_token
Thread-safe in-memory implementation of AccessTokenStore.
InMemoryAccessTokenStore() - Constructor for class com.mastercard.developer.oauth2.core.access_token.InMemoryAccessTokenStore
 
intercept(Interceptor.Chain) - Method in class com.mastercard.developer.oauth2.http.okhttp3.OAuth2Interceptor
 
intercept(HttpRequest, byte[], ClientHttpRequestExecution) - Method in class com.mastercard.developer.oauth2.http.spring.restclient.OAuth2ClientHttpRequestInterceptor
 
issuer(URL) - Method in class com.mastercard.developer.oauth2.config.OAuth2Config.OAuth2ConfigBuilder
Sets the authorization server's unique identifier.

J

JacksonJsonProvider - Class in com.mastercard.developer.oauth2.internal.json
 
JacksonJsonProvider() - Constructor for class com.mastercard.developer.oauth2.internal.json.JacksonJsonProvider
 
jkt() - Method in record class com.mastercard.developer.oauth2.core.access_token.AccessToken
Returns the value of the jkt record component.
jkt() - Method in record class com.mastercard.developer.oauth2.core.access_token.AccessTokenFilter
Returns the value of the jkt record component.
JsonOrgJsonProvider - Class in com.mastercard.developer.oauth2.internal.json
 
JsonOrgJsonProvider() - Constructor for class com.mastercard.developer.oauth2.internal.json.JsonOrgJsonProvider
 
JsonProvider - Interface in com.mastercard.developer.oauth2.internal.json
Provides JSON serialization and deserialization.
JsonProvider.Holder - Class in com.mastercard.developer.oauth2.internal.json
 
Jwk - Class in com.mastercard.developer.oauth2.internal.jose
Represents a JSON Web Key as defined in RFC 7517.
Jws - Class in com.mastercard.developer.oauth2.internal.jose
Provides JWT signing functionality using JWS algorithms.
JwsAlgorithm - Enum Class in com.mastercard.developer.oauth2.internal.jose
Represents signing algorithms supported for JWT signing.
Jwt - Class in com.mastercard.developer.oauth2.internal.jose
Represents a JSON Web Token with header and payload sections.
Jwt() - Constructor for class com.mastercard.developer.oauth2.internal.jose.Jwt
 

K

KeyGenerator - Class in com.mastercard.developer.oauth2.keys
Utility class for generating RSA or EC key pairs.
KeyLoader - Class in com.mastercard.developer.oauth2.keys
Utility class for loading keys.
kid(String) - Method in class com.mastercard.developer.oauth2.config.OAuth2Config.OAuth2ConfigBuilder
Sets the key identifier for the client authentication key.

L

loadKeyPair(InputStream) - Static method in class com.mastercard.developer.oauth2.keys.KeyLoader
Loads a key pair from a JWK input stream.
loadKeyPair(Path) - Static method in class com.mastercard.developer.oauth2.keys.KeyLoader
Loads a key pair from a JWK file.
loadPrivateKey(InputStream) - Static method in class com.mastercard.developer.oauth2.keys.KeyLoader
Loads a private key from an input stream.
loadPrivateKey(InputStream, String, String) - Static method in class com.mastercard.developer.oauth2.keys.KeyLoader
Loads a private key from a PKCS12 keystore input stream.
loadPrivateKey(String, String, String) - Static method in class com.mastercard.developer.oauth2.keys.KeyLoader
Loads a private key from a PKCS12 keystore file.
loadPrivateKey(Path) - Static method in class com.mastercard.developer.oauth2.keys.KeyLoader
Loads a private key from a file.

N

name() - Method in record class com.mastercard.developer.oauth2.http.HttpHeaders.HttpHeader
Returns the value of the name record component.
newBuilder(OAuth2Config) - Static method in class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient
Creates a builder of OAuth2-enabled Java HttpClients.
newBuilder(OAuth2Config, HttpClient.Builder) - Static method in class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient
Creates a builder of OAuth2-enabled Java HttpClients.
newWebSocketBuilder() - Method in class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient
 

O

OAuth2Client - Class in com.mastercard.developer.oauth2.http.feign
An OAuth2-enabled Feign Client.
OAuth2Client(OAuth2Config) - Constructor for class com.mastercard.developer.oauth2.http.feign.OAuth2Client
Creates a new OAuth2-enabled Feign Client.
OAuth2Client(OAuth2Config, Client) - Constructor for class com.mastercard.developer.oauth2.http.feign.OAuth2Client
Creates a new OAuth2-enabled Feign Client.
OAuth2ClientConfigException - Exception in com.mastercard.developer.oauth2.config.exception
Exception for configuration errors.
OAuth2ClientConfigException(String) - Constructor for exception com.mastercard.developer.oauth2.config.exception.OAuth2ClientConfigException
Creates a new configuration exception with the specified message.
OAuth2ClientConfigException(String, Throwable) - Constructor for exception com.mastercard.developer.oauth2.config.exception.OAuth2ClientConfigException
Creates a new configuration exception with the specified message and cause.
OAuth2ClientException - Exception in com.mastercard.developer.oauth2.exception
General exception for OAuth2 client errors.
OAuth2ClientException(String) - Constructor for exception com.mastercard.developer.oauth2.exception.OAuth2ClientException
Creates a new OAuth2ClientException with the specified message.
OAuth2ClientException(String, Throwable) - Constructor for exception com.mastercard.developer.oauth2.exception.OAuth2ClientException
Creates a new OAuth2ClientException with the specified message and cause.
OAuth2ClientHttpRequestInterceptor - Class in com.mastercard.developer.oauth2.http.spring.restclient
An OAuth2 interceptor for Spring RestClient.
OAuth2ClientHttpRequestInterceptor(OAuth2Config) - Constructor for class com.mastercard.developer.oauth2.http.spring.restclient.OAuth2ClientHttpRequestInterceptor
Creates a new OAuth2 interceptor for Spring RestClient.
OAuth2ClientJsonException - Exception in com.mastercard.developer.oauth2.internal.json.exception
Exception for JSON errors.
OAuth2ClientJsonException(String) - Constructor for exception com.mastercard.developer.oauth2.internal.json.exception.OAuth2ClientJsonException
Creates a new JSON exception with the specified message.
OAuth2ClientJsonException(String, Throwable) - Constructor for exception com.mastercard.developer.oauth2.internal.json.exception.OAuth2ClientJsonException
Creates a new JSON exception with the specified message and cause.
OAuth2Config - Class in com.mastercard.developer.oauth2.config
Immutable configuration for OAuth2 clients supporting DPoP-bound access tokens.
OAuth2Config.OAuth2ConfigBuilder - Class in com.mastercard.developer.oauth2.config
Builder for constructing OAuth2Config instances.
OAuth2Filter - Record Class in com.mastercard.developer.oauth2.http.spring.webclient
An OAuth2 filter for Spring WebClient.
OAuth2Filter(OAuth2Config, WebClient.Builder) - Constructor for record class com.mastercard.developer.oauth2.http.spring.webclient.OAuth2Filter
Creates a new OAuth2 filter for Spring WebClient.
OAuth2Filter(ReactiveOAuth2Handler, WebClientHttpAdapter) - Constructor for record class com.mastercard.developer.oauth2.http.spring.webclient.OAuth2Filter
Creates an instance of a OAuth2Filter record class.
OAuth2Handler - Class in com.mastercard.developer.oauth2.core
Acts as an orchestrator for adding OAuth2 authentication to API requests.
OAuth2Handler(OAuth2Config) - Constructor for class com.mastercard.developer.oauth2.core.OAuth2Handler
Creates a new instance of this class with the given configuration.
OAuth2Handler.AccessTokenResponse - Record Class in com.mastercard.developer.oauth2.core
Model for the response from an OAuth2 token endpoint.
OAuth2HttpClient - Class in com.mastercard.developer.oauth2.http.apache
An OAuth2-enabled Apache HttpClient.
OAuth2HttpClient - Class in com.mastercard.developer.oauth2.http.java
An OAuth2-enabled Java HttpClient.
OAuth2HttpClient(OAuth2Config) - Constructor for class com.mastercard.developer.oauth2.http.apache.OAuth2HttpClient
Creates a new OAuth2-enabled Apache HttpClient using a default HttpClient delegate.
OAuth2HttpClient(OAuth2Config, CloseableHttpClient) - Constructor for class com.mastercard.developer.oauth2.http.apache.OAuth2HttpClient
Creates a new OAuth2-enabled Apache HttpClient.
OAuth2HttpClient.Builder - Record Class in com.mastercard.developer.oauth2.http.java
 
OAuth2Interceptor - Class in com.mastercard.developer.oauth2.http.okhttp3
An OAuth2 interceptor for OkHttp.
OAuth2Interceptor(OAuth2Config) - Constructor for class com.mastercard.developer.oauth2.http.okhttp3.OAuth2Interceptor
Creates a new OAuth2 interceptor for OkHttp.
OAuth2Interceptor(OAuth2Config, OkHttpClient.Builder) - Constructor for class com.mastercard.developer.oauth2.http.okhttp3.OAuth2Interceptor
Creates a new OAuth2 interceptor for OkHttp.

P

parse(String) - Method in class com.mastercard.developer.oauth2.internal.json.GsonJsonProvider
 
parse(String) - Method in class com.mastercard.developer.oauth2.internal.json.JacksonJsonProvider
 
parse(String) - Method in class com.mastercard.developer.oauth2.internal.json.JsonOrgJsonProvider
 
parse(String) - Method in interface com.mastercard.developer.oauth2.internal.json.JsonProvider
Parses JSON text into a Map tree.
parseAccessTokenJson(String) - Static method in class com.mastercard.developer.oauth2.core.OAuth2Handler
Parses an OAuth2 token response JSON.
priority(int) - Method in record class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient.Builder
 
proxy() - Method in class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient
 
proxy(ProxySelector) - Method in record class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient.Builder
 
PS256 - Enum constant in enum class com.mastercard.developer.oauth2.internal.jose.JwsAlgorithm
 
put(AccessToken) - Method in interface com.mastercard.developer.oauth2.core.access_token.AccessTokenStore
Adds an access token to the store.
put(AccessToken) - Method in class com.mastercard.developer.oauth2.core.access_token.InMemoryAccessTokenStore
 

R

readBody(Response) - Method in interface com.mastercard.developer.oauth2.http.HttpAdapter
Reads a response body as a string.
resolve(String, URL) - Method in interface com.mastercard.developer.oauth2.core.scope.ScopeResolver
Returns a set of scopes to request for an HTTP request to the given URL with the given method.
resolve(String, URL) - Method in record class com.mastercard.developer.oauth2.core.scope.StaticScopeResolver
 

S

scopeResolver(ScopeResolver) - Method in class com.mastercard.developer.oauth2.config.OAuth2Config.OAuth2ConfigBuilder
Sets the resolver that determines which scopes to request for each API call.
ScopeResolver - Interface in com.mastercard.developer.oauth2.core.scope
Resolves OAuth2 scopes for API requests.
scopes() - Method in record class com.mastercard.developer.oauth2.core.access_token.AccessToken
Returns the value of the scopes record component.
scopes() - Method in record class com.mastercard.developer.oauth2.core.access_token.AccessTokenFilter
Returns the value of the scopes record component.
scopes() - Method in record class com.mastercard.developer.oauth2.core.OAuth2Handler.AccessTokenResponse
Returns the value of the scopes record component.
scopes() - Method in record class com.mastercard.developer.oauth2.core.scope.StaticScopeResolver
Returns the value of the scopes record component.
securityProfile(SecurityProfile) - Method in class com.mastercard.developer.oauth2.config.OAuth2Config.OAuth2ConfigBuilder
Sets the OAuth 2 security profile to use.
SecurityProfile - Enum Class in com.mastercard.developer.oauth2.config
 
send(HttpRequest, HttpResponse.BodyHandler<T>) - Method in class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient
 
sendAccessTokenRequest(Request, URL, String, HttpHeaders) - Method in interface com.mastercard.developer.oauth2.http.HttpAdapter
Sends a token request to an authorization server.
sendAsync(HttpRequest, HttpResponse.BodyHandler<T>) - Method in class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient
 
sendAsync(HttpRequest, HttpResponse.BodyHandler<T>, HttpResponse.PushPromiseHandler<T>) - Method in class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient
 
sendResourceRequest(Request, HttpHeaders) - Method in interface com.mastercard.developer.oauth2.http.HttpAdapter
Sends a resource request to a resource server.
setSignature(String) - Method in class com.mastercard.developer.oauth2.internal.jose.Jwt
Sets the signature for the JWT.
sign(Jwt, PrivateKey, JwsAlgorithm) - Static method in class com.mastercard.developer.oauth2.internal.jose.Jws
Signs a JWT using the specified private key and algorithm.
sslContext() - Method in class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient
 
sslContext(SSLContext) - Method in record class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient.Builder
 
sslParameters() - Method in class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient
 
sslParameters(SSLParameters) - Method in record class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient.Builder
 
StandardHttpHeader - Enum Class in com.mastercard.developer.oauth2.http
HTTP headers used by this project.
StaticDPoPKeyProvider - Class in com.mastercard.developer.oauth2.core.dpop
Provides a static DPoP key pair that remains constant throughout the application lifecycle.
StaticDPoPKeyProvider(KeyPair) - Constructor for class com.mastercard.developer.oauth2.core.dpop.StaticDPoPKeyProvider
Creates a new static DPoP key provider with the specified key pair.
StaticScopeResolver - Record Class in com.mastercard.developer.oauth2.core.scope
A ScopeResolver that always returns a fixed list of scopes regardless of the URL.
StaticScopeResolver(Set<String>) - Constructor for record class com.mastercard.developer.oauth2.core.scope.StaticScopeResolver
Creates a new StaticScopeResolver with the given scopes.

T

tokenEndpoint(URL) - Method in class com.mastercard.developer.oauth2.config.OAuth2Config.OAuth2ConfigBuilder
Sets the OAuth2 token endpoint URL where token requests will be sent.
tokenValue() - Method in record class com.mastercard.developer.oauth2.core.access_token.AccessToken
Returns the value of the tokenValue record component.
tokenValue() - Method in record class com.mastercard.developer.oauth2.core.OAuth2Handler.AccessTokenResponse
Returns the value of the tokenValue record component.
toKeyPair() - Method in class com.mastercard.developer.oauth2.internal.jose.Jwk
Converts this JWK to a key pair.
toString() - Method in class com.mastercard.developer.oauth2.config.OAuth2Config
 
toString() - Method in record class com.mastercard.developer.oauth2.core.access_token.AccessToken
Returns a string representation of this record class.
toString() - Method in record class com.mastercard.developer.oauth2.core.access_token.AccessTokenFilter
Returns a string representation of this record class.
toString() - Method in record class com.mastercard.developer.oauth2.core.OAuth2Handler.AccessTokenResponse
Returns a string representation of this record class.
toString() - Method in record class com.mastercard.developer.oauth2.core.scope.StaticScopeResolver
Returns a string representation of this record class.
toString() - Method in record class com.mastercard.developer.oauth2.http.HttpHeaders.HttpHeader
Returns a string representation of this record class.
toString() - Method in record class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient.Builder
Returns a string representation of this record class.
toString() - Method in record class com.mastercard.developer.oauth2.http.spring.webclient.OAuth2Filter
Returns a string representation of this record class.
tryParse(String) - Method in class com.mastercard.developer.oauth2.internal.json.GsonJsonProvider
 
tryParse(String) - Method in class com.mastercard.developer.oauth2.internal.json.JacksonJsonProvider
 
tryParse(String) - Method in class com.mastercard.developer.oauth2.internal.json.JsonOrgJsonProvider
 
tryParse(String) - Method in interface com.mastercard.developer.oauth2.internal.json.JsonProvider
Parses JSON text into a Map tree.

U

USER_AGENT - Enum constant in enum class com.mastercard.developer.oauth2.http.StandardHttpHeader
 
userAgent(String) - Method in class com.mastercard.developer.oauth2.config.OAuth2Config.OAuth2ConfigBuilder
Sets the User-Agent header value for HTTP requests.
UserAgent - Class in com.mastercard.developer.oauth2.http
Utility class to generate a User-Agent string used in HTTP requests.

V

value() - Method in record class com.mastercard.developer.oauth2.http.HttpHeaders.HttpHeader
Returns the value of the value record component.
value() - Method in enum class com.mastercard.developer.oauth2.http.StandardHttpHeader
 
valueOf(String) - Static method in enum class com.mastercard.developer.oauth2.config.SecurityProfile
Returns the enum constant of this class with the specified name.
valueOf(String) - Static method in enum class com.mastercard.developer.oauth2.http.StandardHttpHeader
Returns the enum constant of this class with the specified name.
valueOf(String) - Static method in enum class com.mastercard.developer.oauth2.internal.jose.JwsAlgorithm
Returns the enum constant of this class with the specified name.
values() - Static method in enum class com.mastercard.developer.oauth2.config.SecurityProfile
Returns an array containing the constants of this enum class, in the order they are declared.
values() - Static method in enum class com.mastercard.developer.oauth2.http.StandardHttpHeader
Returns an array containing the constants of this enum class, in the order they are declared.
values() - Static method in enum class com.mastercard.developer.oauth2.internal.jose.JwsAlgorithm
Returns an array containing the constants of this enum class, in the order they are declared.
version() - Method in class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient
 
version(HttpClient.Version) - Method in record class com.mastercard.developer.oauth2.http.java.OAuth2HttpClient.Builder
 

W

write(Map<String, Object>) - Method in class com.mastercard.developer.oauth2.internal.json.GsonJsonProvider
 
write(Map<String, Object>) - Method in class com.mastercard.developer.oauth2.internal.json.JacksonJsonProvider
 
write(Map<String, Object>) - Method in class com.mastercard.developer.oauth2.internal.json.JsonOrgJsonProvider
 
write(Map<String, Object>) - Method in interface com.mastercard.developer.oauth2.internal.json.JsonProvider
Writes a Map tree to a JSON text.
WWW_AUTHENTICATE - Enum constant in enum class com.mastercard.developer.oauth2.http.StandardHttpHeader
 
A B C D E F G H I J K L N O P R S T U V W 
All Classes and Interfaces|All Packages|Serialized Form