Class OAuth2ClientConfigException
java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
com.mastercard.developer.oauth2.exception.OAuth2ClientException
com.mastercard.developer.oauth2.config.exception.OAuth2ClientConfigException
- All Implemented Interfaces:
Serializable
Exception for configuration errors.
- See Also:
-
Constructor Summary
ConstructorsConstructorDescriptionOAuth2ClientConfigException(String message) Creates a new configuration exception with the specified message.OAuth2ClientConfigException(String message, Throwable cause) Creates a new configuration exception with the specified message and cause. -
Method Summary
Methods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString
-
Constructor Details
-
OAuth2ClientConfigException
Creates a new configuration exception with the specified message. -
OAuth2ClientConfigException
Creates a new configuration exception with the specified message and cause.
-