Interface DPoPKeyProvider
- All Known Implementing Classes:
StaticDPoPKeyProvider
public interface DPoPKeyProvider
DPoP key provider used to supply keys for creating DPoP proofs.
-
Method Summary
Modifier and TypeMethodDescriptionGets the current key to be used for signing DPoP proofs.Returns a key by "kid" (useful in scenarios where the provider returns different key pairs over time).
-
Method Details
-
getCurrentKey
DPoPKey getCurrentKey()Gets the current key to be used for signing DPoP proofs. -
getKey
Returns a key by "kid" (useful in scenarios where the provider returns different key pairs over time).
-