Class StaticDPoPKeyProvider
java.lang.Object
com.mastercard.developer.oauth2.core.dpop.StaticDPoPKeyProvider
- All Implemented Interfaces:
DPoPKeyProvider
Provides a static DPoP key pair that remains constant throughout the application lifecycle.
The key identifier is the public key thumbprint.
This provider is suitable for scenarios where key rotation is not required.
-
Constructor Summary
ConstructorsConstructorDescriptionStaticDPoPKeyProvider(KeyPair keyPair) Creates a new static DPoP key provider with the specified key pair. -
Method Summary
Modifier and TypeMethodDescriptionGets the current key to be used for signing DPoP proofs.Returns a key by "kid" (useful in scenarios where the provider returns different key pairs over time).
-
Constructor Details
-
StaticDPoPKeyProvider
Creates a new static DPoP key provider with the specified key pair. The key identifier is automatically computed from the public key.
-
-
Method Details
-
getCurrentKey
Description copied from interface:DPoPKeyProviderGets the current key to be used for signing DPoP proofs.- Specified by:
getCurrentKeyin interfaceDPoPKeyProvider
-
getKey
Description copied from interface:DPoPKeyProviderReturns a key by "kid" (useful in scenarios where the provider returns different key pairs over time).- Specified by:
getKeyin interfaceDPoPKeyProvider
-