Interface ScopeResolver
- All Known Implementing Classes:
StaticScopeResolver
public interface ScopeResolver
Resolves OAuth2 scopes for API requests.
Implementations determine which scopes to include in token requests based on the HTTP method and target URL.
-
Method Summary
-
Method Details
-
resolve
Returns a set of scopes to request for an HTTP request to the given URL with the given method. -
allScopes
Returns all possible scopes that can be requested.
-